==> Uclip-v1_12.zip: Uclip/lua/autorun/sv_uclip.lua <==
-- Written by Team Ulysses, http://ulyssesmod.net/
module( "Uclip", package.seeall )
if not SERVER then return end

hasPropProtection = false -- Chaussette's Prop Protection (preferred over PropSecure)
propProtectionFn = nil -- Function to call to see if a prop belongs to a player. We have to fetch it from a local so we'll store it here.

hasSPropProtection = false -- Simple Prop Protection by Spacetech
SPropProtectionFn = nil -- Function to call to see if a prop belongs to a player. We have to fetch it from a local so we'll store it here.

hasEPS = false -- EPS by Conna
hasPropSecure = false -- Prop Secure by Conna
hasProtector = false -- Protector by Conna

-- We'll check status of protectors in this init
function initUclip()
	local t = hook.GetTable()
	local fn
	if t.CanTool[ 0 ] then -- ULib
		fn = t.CanTool[ 0 ].PropProtection
	else
		fn = t.CanTool.PropProtection
	end

	hasPropProtection = type( fn ) == "function"
	
	if hasPropProtection then
		-- We're going to get the function we need now. It's local so this is a bit dirty			
		local gi = debug.getinfo( fn )
		for i=1, gi.nups do
			local k, v = debug.getupvalue( fn, i )
			if k == "Appartient" then
				propProtectionFn = v
			end
		end
	end
 
	local fn
	if t.CanTool[ 0 ] then -- ULib
		fn = t.EntityRemoved[ 0 ][ "SPropProtection.EntityRemoved" ]
	else
		fn = t.CanTool[ "SPropProtection.EntityRemoved" ]
	end
	
	hasSPropProtection = type( fn ) == "function"
	
	if hasSPropProtection then
		local gi = debug.getinfo( fn )
		for i=1, gi.nups do
			local k, v = debug.getupvalue( fn, i )
			if k == "SPropProtection" then
				SPropProtectionFn = v.PlayerCanTouch
			end
		end
	end

	hasEPS = type( eps ) == "table"
	hasPropSecure = type( PropSecure ) == "table"
	hasProtector = type( Protector ) == "table"
	
	if not hasPropProtection and not hasSPropProtection and not hasEPS and not hasPropSecure and not hasProtector then
		noProtection = true
		umsg.Start( "UclipNoProtection" ) -- In case there's anyone connected right now.
		umsg.End()
	end
end
hook.Add( "Initialize", "UclipInitialize", initUclip )

-- Tell them there's no prop protection in the event there isn't.
function initialSpawn( ply )
	if noProtection then
		umsg.Start( "UclipNoProtection", ply )
		umsg.End()
	end
end
hook.Add( "PlayerInitialSpawn", "UclipInitialSpawn", initialSpawn )

-- Block the valve noclip-unstuck. Can go through walls.
function noclip( ply )
	if ply:GetMoveType() == MOVETYPE_NOCLIP then
		local pos = ply:GetPos()
		timer.Simple( FrameTime() * 0.5, function() 
			ply:SetPos( pos )
		end )
	end
end
hook.Add( "PlayerNoClip", "UclipNoclip", noclip )	

-- This function checks the protector to see if ownership has changed from what we think it is. Notifies player for c-side prediction too.
function updateOwnership( ply, ent )
	if noProtection then return end -- No point on going on
	if not ent.Uclip then ent.Uclip = {} end -- Initialize table

	local owns
	if hasPropProtection then -- Chaussette's Prop Protection (preferred over PropSecure)
		owns = propProtectionFn( ply, ent )
	elseif hasSPropProtection then -- Simple Prop Protection by Spacetech
		if ent:GetNetworkedString( "Owner" ) ~= "" then -- So it doesn't give an unowned prop
 			owns = SPropProtectionFn( ply, ent )
		else
			owns = false
 		end
 	elseif hasEPS then -- EPS
 		owns = eps.CanPlayerTouch( ply, ent )
	elseif hasPropSecure then -- PropSecure
		owns = PropSecure.IsPlayers( ply, ent )
	elseif hasProtector then -- Protector
		owns = Protector.Owner( ent ) == ply:UniqueID()
	end
	
	if owns == false then -- More convienent to store as nil, takes less memory and bandwidth!
		owns = nil
	end
	
	if ent.Uclip[ ply ] ~= owns then
		ent.Uclip[ ply ] = owns
		umsg.Start( "UclipOwnershipUpdate", ply )
			umsg.Entity( ent )
			umsg.Bool( owns )
		umsg.End()
	end
end

==> Uclip-v1_13.zip: Uclip/lua/autorun/sv_uclip.lua <==
-- Written by Team Ulysses, http://ulyssesmod.net/
module( "Uclip", package.seeall )
if not SERVER then return end

hasCPPI = false -- Common Prop Protection Interface. Preferred over all else.

hasPropProtection = false -- Chaussette's Prop Protection (preferred over PropSecure)
propProtectionFn = nil -- Function to call to see if a prop belongs to a player. We have to fetch it from a local so we'll store it here.

hasSPropProtection = false -- Simple Prop Protection by Spacetech
SPropProtectionFn = nil -- Function to call to see if a prop belongs to a player. We have to fetch it from a local so we'll store it here.

hasEPS = false -- EPS by Conna
hasPropSecure = false -- Prop Secure by Conna
hasProtector = false -- Protector by Conna

-- We'll check status of protectors in this init
function initUclip()
	hasCPPI = (type( CPPI ) == "table")
	
	local t = hook.GetTable()
	
	local fn = t.CanTool.PropProtection
	hasPropProtection = type( fn ) == "function"
	
	if hasPropProtection then
		-- We're going to get the function we need now. It's local so this is a bit dirty			
		local gi = debug.getinfo( fn )
		for i=1, gi.nups do
			local k, v = debug.getupvalue( fn, i )
			if k == "Appartient" then
				propProtectionFn = v
			end
		end
	end
 
	local fn = t.CanTool[ "SPropProtection.EntityRemoved" ]	
	hasSPropProtection = type( fn ) == "function"
	
	if hasSPropProtection then
		local gi = debug.getinfo( fn )
		for i=1, gi.nups do
			local k, v = debug.getupvalue( fn, i )
			if k == "SPropProtection" then
				SPropProtectionFn = v.PlayerCanTouch
			end
		end
	end

	hasEPS = type( eps ) == "table"
	hasPropSecure = type( PropSecure ) == "table"
	hasProtector = type( Protector ) == "table"
	
	if not hasCPPI and not hasPropProtection and not hasSPropProtection and not hasEPS and not hasPropSecure and not hasProtector then
		noProtection = true
		umsg.Start( "UclipNoProtection" ) -- In case there's anyone connected right now.
		umsg.End()
	end
end
hook.Add( "Initialize", "UclipInitialize", initUclip )

-- Tell them there's no prop protection in the event there isn't.
function initialSpawn( ply )
	if noProtection then
		umsg.Start( "UclipNoProtection", ply )
		umsg.End()
	end
end
hook.Add( "PlayerInitialSpawn", "UclipInitialSpawn", initialSpawn )

-- Block the valve noclip-unstuck. Can go through walls.
function noclip( ply )
	if ply:GetMoveType() == MOVETYPE_NOCLIP then
		local pos = ply:GetPos()
		timer.Simple( FrameTime() * 0.5, function() 
			ply:SetPos( pos )
		end )
	end
end
hook.Add( "PlayerNoClip", "UclipNoclip", noclip )	

-- This function checks the protector to see if ownership has changed from what we think it is. Notifies player for c-side prediction too.
function updateOwnership( ply, ent )
	if noProtection then return end -- No point on going on
	if not ent.Uclip then ent.Uclip = {} end -- Initialize table

	local owns
	if hasCPPI then
		owns = ent:CPPICanPhysgun( ply )
	elseif hasPropProtection then -- Chaussette's Prop Protection (preferred over PropSecure)
		owns = propProtectionFn( ply, ent )
	elseif hasSPropProtection then -- Simple Prop Protection by Spacetech
		if ent:GetNetworkedString( "Owner" ) ~= "" then -- So it doesn't give an unowned prop
 			owns = SPropProtectionFn( ply, ent )
		else
			owns = false
 		end
 	elseif hasEPS then -- EPS
 		owns = eps.CanPlayerTouch( ply, ent )
	elseif hasPropSecure then -- PropSecure
		owns = PropSecure.IsPlayers( ply, ent )
	elseif hasProtector then -- Protector
		owns = Protector.Owner( ent ) == ply:UniqueID()
	end
	
	if owns == false then -- More convienent to store as nil, takes less memory and bandwidth!
		owns = nil
	end
	
	if ent.Uclip[ ply ] ~= owns then
		ent.Uclip[ ply ] = owns
		umsg.Start( "UclipOwnershipUpdate", ply )
			umsg.Entity( ent )
			umsg.Bool( owns )
		umsg.End()
	end
end
